/***************************************

    This is part of frox: A simple transparent FTP proxy
    Copyright (C) 2000 James Hollingshead

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

  cache.h -- header file containing the interface for cache modules.

  ***************************************/
/* --------------------------------------------------------------- **
** This file contains the following functions for each caching module:
**
** X_geninit(char **cacheopts, char *chroot);
** Called on module load. Opts is a list of config file options
** destined for the cache. chroot is the directory we are chrooted to
** - module may need to strip this from the front of any file name
** options.
**
** X_retr_start();
** Called at the start of each file retrieval. If the cache code wants
** to return the file it should return a file descriptor. If not it
** should return -1, and the RETR command will be passed on to the
** server. 
**
** X_inc_data();
** Called with each piece of incoming data. Cache code can either
** store or modify this (or both). 
**
** X_retr_end();
** Called at the end of each file retrieval to allow cleanup.
** ------------------------------------------------------------- */

#ifdef USE_LCACHE
int l_geninit(void);
int l_retr_start(const sstr * host, const sstr * file, const sstr * mdtm,
		 int size, int offset, int type);
void l_inc_data(sstr * inc);
int l_retr_end(void);
#else
# define l_geninit NULL
# define l_retr_start NULL
# define l_inc_data NULL
# define l_retr_end NULL
#endif

#ifdef USE_HCACHE
int s_geninit(void);
int s_retr_start(const sstr * host, const sstr * file, const sstr * mdtm,
		 int size, int offst, int type);
void s_inc_data(sstr * inc);
int s_retr_end(void);
#else
# define s_geninit NULL
# define s_retr_start NULL
# define s_inc_data NULL
# define s_retr_end NULL
#endif

#ifdef DO_VSCAN
void vscan_init(void);
void vscan_new(int sz);
void vscan_inc(sstr * inc);
int vscan_end(void);
int vscan_parsed_reply(int code, sstr * msg);
#else
static inline void vscan_init(void)
{
};
static inline void vscan_new(int sz)
{
};
static inline void vscan_inc(sstr * inc)
{
};
static inline int vscan_end(void)
{
	return -1;
};
static inline int vscan_parsed_reply(int code, sstr * msg)
{
	return FALSE;
};
#endif

#define VSCAN_OK -1
#define VSCAN_FAIL -2
